@@ -264,10 +264,11 @@
 #include <stdint.h>
 #include <string.h>
 #include <sched.h>
+#include <unistd.h>
 
 #include "config.h"
 #include "compat-getcpu.h"
-#include <urcu.h>
+#include <urcu-pointer.h>
 #include <urcu-call-rcu.h>
 #include <urcu-flavor.h>
 #include <urcu/arch.h>
@@ -1798,6 +1799,9 @@ int cds_lfht_destroy(struct cds_lfht *ht, pthread_attr_t **attr)
 	free_split_items_count(ht);
 	if (attr)
 		*attr = ht->resize_attr;
+	ret = pthread_mutex_destroy(&ht->resize_mutex);
+	if (ret)
+		ret = -EBUSY;
 	poison_free(ht);
 end:
 	return ret;
